==> dart_icalendar-1.0.0.tar.gz: test/dart_icalendar_test.dart <==
import 'dart:io';

import 'package:dart_icalendar/models/alarm_model.dart';
import 'package:dart_icalendar/models/attachment_model.dart';
import 'package:dart_icalendar/models/event_model.dart';
import 'package:dart_icalendar/models/icalendar_model.dart';
import 'package:dart_icalendar/models/person_model.dart';
import 'package:dart_icalendar/models/recurrence_model.dart';
import 'package:test/test.dart';

void main() {
  final iCalendarString = 'BEGIN:VCALENDAR\r\n'
      'PRODID:-//Apollocode Inc//EN\r\n'
      'X-WR-CALNAME:Test Calendar\r\n'
      'X-WR-CALDESC:This is a test calendar\r\n'
      'CALSCALE:GREGORIAN\r\n'
      'BEGIN:VEVENT\r\n'
      'DTSTART:20220418T160000Z\r\n'
      'DTEND:20220418T170000Z\r\n'
      'UID:12345\r\n'
      'DESCRIPTION:This is a test event.\r\n'
      'SUMMARY:Test Event\r\n'
      'END:VEVENT\r\n'
      'END:VCALENDAR\r\n';

  group('ICalendar', () {
    final iCalendar = ICalendar(
      '-//Apollocode Inc//EN',
      events: [
        Event(
          uid: '12345',
          summary: 'Test Event',
          description: 'This is a test event.',
          startDate: DateTime.utc(2022, 4, 18, 16),
          endDate: DateTime.utc(2022, 4, 18, 17),
        )
      ],
      properties: [
        'X-WR-CALNAME:Test Calendar',
        'X-WR-CALDESC:This is a test calendar',
        'CALSCALE:GREGORIAN'
      ],
    );

    test('addProperty() adds a new property to the list of properties', () {
      final iCalendar = ICalendar(
        '-//Apollocode Inc//EN',
        events: [],
        properties: ['X-WR-CALNAME:Test Calendar'],
      );

      iCalendar.addProperty('X-WR-CALDESC:This is a test calendar');

      expect(
        iCalendar.properties,
        equals([
          'X-WR-CALNAME:Test Calendar',
          'X-WR-CALDESC:This is a test calendar',
        ]),
      );
    });

    test(
        'fromICalString() returns an iCalendar object with the expected properties and events',
        () {
      final parsedICalendar = ICalendar.fromICalString(iCalendarString);

      expect(parsedICalendar.prodId, equals(iCalendar.prodId));
      expect(
          parsedICalendar.properties ??
              [].where((p) => !p.startsWith('VERSION:')).toList(),
          equals(iCalendar.properties));
      expect(parsedICalendar.events?.first, equals(iCalendar.events?.first),
          reason:
              'Parsed event: ${parsedICalendar.events?.first.toICalString()}\nExpected event: ${iCalendar.events?.first.toICalString()}');
    });

    test(
        'toICalString() returns the expected string representation of an event',
        () {
      final event = Event(
        uid: '12345',
        summary: 'Test Event',
        description: 'This is a test event.',
        startDate: DateTime.utc(2022, 4, 18, 16),
        endDate: DateTime.utc(2022, 4, 18, 17),
      );

      final eventString = 'BEGIN:VEVENT\r\n'
          'DTSTART:20220418T160000Z\r\n'
          'DTEND:20220418T170000Z\r\n'
          'UID:12345\r\n'
          'DESCRIPTION:This is a test event.\r\n'
          'SUMMARY:Test Event\r\n'
          'END:VEVENT\r\n';

      expect(event.toICalString(), equals(eventString));
    });

    test(
        'toICalString() returns the expected string representation of an iCalendar',
        () {
      expect(iCalendar.toICalString(), equals(iCalendarString));
    });

    test('addEvent() adds a new event to the list of events', () {
      final iCalendar = ICalendar(
        '-//Apollocode Inc//EN',
        events: [
          Event(
            uid: '12345',
            summary: 'Test Event',
            description: 'This is a test event.',
            startDate: DateTime.utc(2022, 4, 18, 16),
            endDate: DateTime.utc(2022, 4, 18, 17),
          )
        ],
        properties: [
          'X-WR-CALNAME:Test Calendar',
          'X-WR-CALDESC:This is a test calendar',
          'CALSCALE:GREGORIAN'
        ],
      );

      iCalendar.addEvent(Event(
        uid: '67890',
        summary: 'Another Test Event',
        description: 'This is another test event.',
        startDate: DateTime.utc(2022, 4, 20, 10),
        endDate: DateTime.utc(2022, 4, 20, 11),
      ));

      expect(
        iCalendar.events,
        equals([
          Event(
            uid: '12345',
            summary: 'Test Event',
            description: 'This is a test event.',
            startDate: DateTime.utc(2022, 4, 18, 16),
            endDate: DateTime.utc(2022, 4, 18, 17),
          ),
          Event(
            uid: '67890',
            summary: 'Another Test Event',
            description: 'This is another test event.',
            startDate: DateTime.utc(2022, 4, 20, 10),
            endDate: DateTime.utc(2022, 4, 20, 11),
          ),
        ]),
      );
    });
  });

  group('Alarm', () {
    final alarm = Alarm(
      duration: Duration(minutes: 15),
      description: '15 minutes before the event',
    );

    test('toICalString() returns the expected string representation', () {
      final icalString =
          'BEGIN:VALARM\nTRIGGER:-PT15M\nACTION:DISPLAY\nDESCRIPTION:15 minutes before the event\nEND:VALARM\n';
      expect(alarm.toICalString(), equals(icalString));
    });

    test('fromICalString() returns a valid Alarm object', () {
      final icalString =
          'BEGIN:VALARM\nTRIGGER:-PT15M\nACTION:DISPLAY\nDESCRIPTION:15 minutes before the event\nEND:VALARM\n';
      final parsedAlarm = Alarm.fromICalString(icalString);

      expect(parsedAlarm, equals(alarm));
    });

    test('copyWith() creates a copy of the Alarm object with the new values',
        () {
      final newAlarm = alarm.copyWith(
        duration: Duration(hours: 1),
        description: '1 hour before the event',
      );

      expect(
        newAlarm,
        equals(
          Alarm(
            duration: Duration(hours: 1),
            description: '1 hour before the event',
          ),
        ),
      );
    });

    test('toMap() returns a Map with the Alarm object values', () {
      final expectedMap = {
        'duration': alarm.duration.inMilliseconds,
        'description': alarm.description,
      };

      expect(alarm.toMap(), equals(expectedMap));
    });

    test('fromMap() returns a valid Alarm object', () {
      final alarmMap = {
        'duration': alarm.duration.inMilliseconds,
        'description': alarm.description,
      };

      expect(Alarm.fromMap(alarmMap), equals(alarm));
    });

    test('toJson() returns a JSON string with the Alarm object values', () {
      final expectedJson =
          '{"duration":900000,"description":"15 minutes before the event"}';

      expect(alarm.toJson(), equals(expectedJson));
    });

    test('fromJson() returns a valid Alarm object', () {
      final json =
          '{"duration":900000,"description":"15 minutes before the event"}';
      expect(Alarm.fromJson(json), equals(alarm));
    });

    test('toString() returns a string representation of the Alarm object', () {
      expect(
        alarm.toString(),
        equals(
            'Alarm(duration: ${alarm.duration}, description: ${alarm.description})'),
      );
    });

    test(
        'operator == returns true only if two Alarm objects have the same properties',
        () {
      final equalAlarm = Alarm(
        duration: Duration(minutes: 15),
        description: '15 minutes before the event',
      );

      final differentAlarm = Alarm(
        duration: Duration(hours: 1),
        description: '1 hour before the event',
      );

      expect(alarm == equalAlarm, isTrue);
      expect(alarm == differentAlarm, isFalse);
    });

    test('hashCode returns the hash value of the Alarm object', () {
      final expectedHashCode =
          alarm.duration.hashCode ^ alarm.description.hashCode;
      expect(alarm.hashCode, equals(expectedHashCode));
    });
  });

  group('Attachment', () {
    test('toICalString should return correct string without file name', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
      );
      expect(attachment.toICalString(), 'ATTACH;FMTTYPE=application/pdf');
    });
    test('toICalString should return correct string with file name', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment.toICalString(),
          'ATTACH;FILENAME=Document.pdf;FMTTYPE=application/pdf:https://example.com/document.pdf');
    });

    test('fromICalString should parse correct attachment with file name', () {
      final icalString =
          'ATTACH;FILENAME=Notifications;FMTTYPE=application/vnd.google-apps.document:https://drive.google.com/open?id=1g_asb4VhQlllybUleP96GiPAvtFNlEQ6z2okMEVGP-E&authuser=0';
      final attachment = Attachment.fromICalString(icalString);
      expect(
          attachment.uri,
          Uri.parse(
              'https://drive.google.com/open?id=1g_asb4VhQlllybUleP96GiPAvtFNlEQ6z2okMEVGP-E&authuser=0'));
      expect(attachment.mimeType, 'application/vnd.google-apps.document');
      expect(attachment.fileName, 'Notifications');
    });

    test('toJson and fromJson should work correctly', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final jsonStr = attachment.toJson();
      final parsedAttachment = Attachment.fromJson(jsonStr);
      expect(parsedAttachment, attachment);
    });

    test('copyWith should create a new attachment with updated properties', () {
      final originalAttachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final newAttachment = originalAttachment.copyWith(
        uri: Uri.parse('https://example.com/new.pdf'),
        fileName: 'New.pdf',
      );
      expect(newAttachment.uri, Uri.parse('https://example.com/new.pdf'));
      expect(newAttachment.mimeType, 'application/pdf');
      expect(newAttachment.fileName, 'New.pdf');
    });

    test('toString should return a string representation of the attachment',
        () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment.toString(),
          'Attachment(uri: https://example.com/document.pdf, mimeType: application/pdf, fileName: Document.pdf)');
    });

    test('== should return true for equal attachments', () {
      final attachment1 = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final attachment2 = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment1 == attachment2, true);
    });
  });

  group('Event iCalendar serialization', () {
    test('toICalString() should return a valid iCalendar string', () {
      final event = Event(
        uid: '1234',
        summary: 'Test event',
        description: 'This is a test event',
        startDate: DateTime.utc(2022, 1, 1, 10, 0),
        endDate: DateTime.utc(2022, 1, 1, 12, 0),
        organizer: Organizer(
          name: 'John Smith',
          email: 'john@example.com',
        ),
        recurrenceRule: RecurrenceRule(
          frequency: Frequency.WEEKLY,
          interval: 2,
          count: 10,
        ),
      );

      final expected =
          'BEGIN:VEVENT\r\nDTSTART:20220101T100000Z\r\nDTEND:20220101T120000Z\r\nRRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=10\r\nORGANIZER;CN=John Smith:mailto:john@example.com\r\nUID:1234\r\nDESCRIPTION:This is a test event\r\nSUMMARY:Test event\r\nEND:VEVENT\r\n';

      expect(event.toICalString(), equals(expected));
    });

    test('fromICalString() should parse a valid iCalendar string', () {
      final icalString =
          'BEGIN:VEVENT\nUID:1234\nSUMMARY:Test event\nDESCRIPTION:This is a test event\nDTSTART:20220101T100000Z\nDTEND:20220101T120000Z\nORGANIZER;CN="John Smith":mailto:john@example.com\nRRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=10\nEND:VEVENT\n';

      final expected = Event(
        uid: '1234',
        summary: 'Test event',
        description: 'This is a test event',
        startDate: DateTime.utc(2022, 1, 1, 10, 0),
        endDate: DateTime.utc(2022, 1, 1, 12, 0),
        organizer: Organizer(
          name: 'John Smith',
          email: 'john@example.com',
        ),
        recurrenceRule: RecurrenceRule(
          frequency: Frequency.WEEKLY,
          interval: 2,
          count: 10,
        ),
      );

      expect(Event.fromICalString(icalString), equals(expected));
    });
  });

  group('ics file import', () {
    test('should parse a valid ics file', () {
      final icsFile = File('test/ics/icalendar.ics');
      final icsString = icsFile.readAsStringSync();

      final calendar1 = ICalendar.fromICalString(icsString);
      final calendar2 = ICalendar.fromICalString(calendar1.toICalString());

      expect(calendar1.events?.length, calendar2.events?.length);
      expect(calendar1.toICalString(), calendar2.toICalString());
      expect(calendar1.properties?.length, calendar2.properties?.length);
    });
  });

  // test('custom/icalendar_parser#1', () {
  //   final icsFile = File('test/ics/custom.ics');
  //   final icsString = icsFile.readAsStringSync();

  //   final calendar = ICalendar.fromICalString(icsString);
  //   expect(calendar.toICalString(), icsString);
  // });
}

==> dart_icalendar-1.0.2.tar.gz: test/dart_icalendar_test.dart <==
import 'dart:io';

import 'package:dart_icalendar/models/alarm_model.dart';
import 'package:dart_icalendar/models/attachment_model.dart';
import 'package:dart_icalendar/models/event_model.dart';
import 'package:dart_icalendar/models/icalendar_model.dart';
import 'package:dart_icalendar/models/person_model.dart';
import 'package:dart_icalendar/models/recurrence_model.dart';
import 'package:test/test.dart';

void main() {
  final iCalendarString = 'BEGIN:VCALENDAR\r\n'
      'PRODID:-//Apollocode Inc//EN\r\n'
      'X-WR-CALNAME:Test Calendar\r\n'
      'X-WR-CALDESC:This is a test calendar\r\n'
      'CALSCALE:GREGORIAN\r\n'
      'BEGIN:VEVENT\r\n'
      'DTSTART:20220418T160000Z\r\n'
      'DTEND:20220418T170000Z\r\n'
      'UID:12345\r\n'
      'DESCRIPTION:This is a test event.\r\n'
      'SUMMARY:Test Event\r\n'
      'END:VEVENT\r\n'
      'END:VCALENDAR\r\n';

  group('ICalendar', () {
    final iCalendar = ICalendar(
      prodId: '-//Apollocode Inc//EN',
      events: [
        Event(
          uid: '12345',
          summary: 'Test Event',
          description: 'This is a test event.',
          startDate: DateTime.utc(2022, 4, 18, 16),
          endDate: DateTime.utc(2022, 4, 18, 17),
        )
      ],
      properties: [
        'X-WR-CALNAME:Test Calendar',
        'X-WR-CALDESC:This is a test calendar',
        'CALSCALE:GREGORIAN'
      ],
    );

    test('addProperty() adds a new property to the list of properties', () {
      final iCalendar = ICalendar(
        prodId: '-//Apollocode Inc//EN',
        events: [],
        properties: ['X-WR-CALNAME:Test Calendar'],
      );

      iCalendar.addProperty('X-WR-CALDESC:This is a test calendar');

      expect(
        iCalendar.properties,
        equals([
          'X-WR-CALNAME:Test Calendar',
          'X-WR-CALDESC:This is a test calendar',
        ]),
      );
    });

    test(
        'fromICalString() returns an iCalendar object with the expected properties and events',
        () {
      final parsedICalendar = ICalendar.fromICalString(iCalendarString);

      expect(parsedICalendar.prodId, equals(iCalendar.prodId));
      expect(
          parsedICalendar.properties ??
              [].where((p) => !p.startsWith('VERSION:')).toList(),
          equals(iCalendar.properties));
      expect(parsedICalendar.events?.first, equals(iCalendar.events?.first),
          reason:
              'Parsed event: ${parsedICalendar.events?.first.toICalString()}\nExpected event: ${iCalendar.events?.first.toICalString()}');
    });

    test(
        'toICalString() returns the expected string representation of an event',
        () {
      final event = Event(
        uid: '12345',
        summary: 'Test Event',
        description: 'This is a test event.',
        startDate: DateTime.utc(2022, 4, 18, 16),
        endDate: DateTime.utc(2022, 4, 18, 17),
      );

      final eventString = 'BEGIN:VEVENT\r\n'
          'DTSTART:20220418T160000Z\r\n'
          'DTEND:20220418T170000Z\r\n'
          'UID:12345\r\n'
          'DESCRIPTION:This is a test event.\r\n'
          'SUMMARY:Test Event\r\n'
          'END:VEVENT\r\n';

      expect(event.toICalString(), equals(eventString));
    });

    test(
        'toICalString() returns the expected string representation of an iCalendar',
        () {
      expect(iCalendar.toICalString(), equals(iCalendarString));
    });

    test('addEvent() adds a new event to the list of events', () {
      final iCalendar = ICalendar(
        prodId: '-//Apollocode Inc//EN',
        events: [
          Event(
            uid: '12345',
            summary: 'Test Event',
            description: 'This is a test event.',
            startDate: DateTime.utc(2022, 4, 18, 16),
            endDate: DateTime.utc(2022, 4, 18, 17),
          )
        ],
        properties: [
          'X-WR-CALNAME:Test Calendar',
          'X-WR-CALDESC:This is a test calendar',
          'CALSCALE:GREGORIAN'
        ],
      );

      iCalendar.addEvent(Event(
        uid: '67890',
        summary: 'Another Test Event',
        description: 'This is another test event.',
        startDate: DateTime.utc(2022, 4, 20, 10),
        endDate: DateTime.utc(2022, 4, 20, 11),
      ));

      expect(
        iCalendar.events,
        equals([
          Event(
            uid: '12345',
            summary: 'Test Event',
            description: 'This is a test event.',
            startDate: DateTime.utc(2022, 4, 18, 16),
            endDate: DateTime.utc(2022, 4, 18, 17),
          ),
          Event(
            uid: '67890',
            summary: 'Another Test Event',
            description: 'This is another test event.',
            startDate: DateTime.utc(2022, 4, 20, 10),
            endDate: DateTime.utc(2022, 4, 20, 11),
          ),
        ]),
      );
    });
  });

  group('Alarm', () {
    final alarm = Alarm(
      duration: Duration(minutes: 15),
      description: '15 minutes before the event',
    );

    test('toICalString() returns the expected string representation', () {
      final icalString =
          'BEGIN:VALARM\nTRIGGER:-PT15M\nACTION:DISPLAY\nDESCRIPTION:15 minutes before the event\nEND:VALARM\n';
      expect(alarm.toICalString(), equals(icalString));
    });

    test('fromICalString() returns a valid Alarm object', () {
      final icalString =
          'BEGIN:VALARM\nTRIGGER:-PT15M\nACTION:DISPLAY\nDESCRIPTION:15 minutes before the event\nEND:VALARM\n';
      final parsedAlarm = Alarm.fromICalString(icalString);

      expect(parsedAlarm, equals(alarm));
    });

    test('copyWith() creates a copy of the Alarm object with the new values',
        () {
      final newAlarm = alarm.copyWith(
        duration: Duration(hours: 1),
        description: '1 hour before the event',
      );

      expect(
        newAlarm,
        equals(
          Alarm(
            duration: Duration(hours: 1),
            description: '1 hour before the event',
          ),
        ),
      );
    });

    test('toMap() returns a Map with the Alarm object values', () {
      final expectedMap = {
        'duration': alarm.duration.inMilliseconds,
        'description': alarm.description,
      };

      expect(alarm.toMap(), equals(expectedMap));
    });

    test('fromMap() returns a valid Alarm object', () {
      final alarmMap = {
        'duration': alarm.duration.inMilliseconds,
        'description': alarm.description,
      };

      expect(Alarm.fromMap(alarmMap), equals(alarm));
    });

    test('toJson() returns a JSON string with the Alarm object values', () {
      final expectedJson =
          '{"duration":900000,"description":"15 minutes before the event"}';

      expect(alarm.toJson(), equals(expectedJson));
    });

    test('fromJson() returns a valid Alarm object', () {
      final json =
          '{"duration":900000,"description":"15 minutes before the event"}';
      expect(Alarm.fromJson(json), equals(alarm));
    });

    test('toString() returns a string representation of the Alarm object', () {
      expect(
        alarm.toString(),
        equals(
            'Alarm(duration: ${alarm.duration}, description: ${alarm.description})'),
      );
    });

    test(
        'operator == returns true only if two Alarm objects have the same properties',
        () {
      final equalAlarm = Alarm(
        duration: Duration(minutes: 15),
        description: '15 minutes before the event',
      );

      final differentAlarm = Alarm(
        duration: Duration(hours: 1),
        description: '1 hour before the event',
      );

      expect(alarm == equalAlarm, isTrue);
      expect(alarm == differentAlarm, isFalse);
    });

    test('hashCode returns the hash value of the Alarm object', () {
      final expectedHashCode =
          alarm.duration.hashCode ^ alarm.description.hashCode;
      expect(alarm.hashCode, equals(expectedHashCode));
    });
  });

  group('Attachment', () {
    test('toICalString should return correct string without file name', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
      );
      expect(attachment.toICalString(), 'ATTACH;FMTTYPE=application/pdf');
    });
    test('toICalString should return correct string with file name', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment.toICalString(),
          'ATTACH;FILENAME=Document.pdf;FMTTYPE=application/pdf:https://example.com/document.pdf');
    });

    test('fromICalString should parse correct attachment with file name', () {
      final icalString =
          'ATTACH;FILENAME=Notifications;FMTTYPE=application/vnd.google-apps.document:https://drive.google.com/open?id=1g_asb4VhQlllybUleP96GiPAvtFNlEQ6z2okMEVGP-E&authuser=0';
      final attachment = Attachment.fromICalString(icalString);
      expect(
          attachment.uri,
          Uri.parse(
              'https://drive.google.com/open?id=1g_asb4VhQlllybUleP96GiPAvtFNlEQ6z2okMEVGP-E&authuser=0'));
      expect(attachment.mimeType, 'application/vnd.google-apps.document');
      expect(attachment.fileName, 'Notifications');
    });

    test('toJson and fromJson should work correctly', () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final jsonStr = attachment.toJson();
      final parsedAttachment = Attachment.fromJson(jsonStr);
      expect(parsedAttachment, attachment);
    });

    test('copyWith should create a new attachment with updated properties', () {
      final originalAttachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final newAttachment = originalAttachment.copyWith(
        uri: Uri.parse('https://example.com/new.pdf'),
        fileName: 'New.pdf',
      );
      expect(newAttachment.uri, Uri.parse('https://example.com/new.pdf'));
      expect(newAttachment.mimeType, 'application/pdf');
      expect(newAttachment.fileName, 'New.pdf');
    });

    test('toString should return a string representation of the attachment',
        () {
      final attachment = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment.toString(),
          'Attachment(uri: https://example.com/document.pdf, mimeType: application/pdf, fileName: Document.pdf)');
    });

    test('== should return true for equal attachments', () {
      final attachment1 = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      final attachment2 = Attachment(
        uri: Uri.parse('https://example.com/document.pdf'),
        mimeType: 'application/pdf',
        fileName: 'Document.pdf',
      );
      expect(attachment1 == attachment2, true);
    });
  });

  group('Event iCalendar serialization', () {
    test('toICalString() should return a valid iCalendar string', () {
      final event = Event(
        uid: '1234',
        summary: 'Test event',
        description: 'This is a test event',
        startDate: DateTime.utc(2022, 1, 1, 10, 0),
        endDate: DateTime.utc(2022, 1, 1, 12, 0),
        organizer: Organizer(
          name: 'John Smith',
          email: 'john@example.com',
        ),
        recurrenceRule: RecurrenceRule(
          frequency: Frequency.WEEKLY,
          interval: 2,
          count: 10,
        ),
      );

      final expected =
          'BEGIN:VEVENT\r\nDTSTART:20220101T100000Z\r\nDTEND:20220101T120000Z\r\nRRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=10\r\nORGANIZER;CN=John Smith:mailto:john@example.com\r\nUID:1234\r\nDESCRIPTION:This is a test event\r\nSUMMARY:Test event\r\nEND:VEVENT\r\n';

      expect(event.toICalString(), equals(expected));
    });

    test('fromICalString() should parse a valid iCalendar string', () {
      final icalString =
          'BEGIN:VEVENT\nUID:1234\nSUMMARY:Test event\nDESCRIPTION:This is a test event\nDTSTART:20220101T100000Z\nDTEND:20220101T120000Z\nORGANIZER;CN="John Smith":mailto:john@example.com\nRRULE:FREQ=WEEKLY;INTERVAL=2;COUNT=10\nEND:VEVENT\n';

      final expected = Event(
        uid: '1234',
        summary: 'Test event',
        description: 'This is a test event',
        startDate: DateTime.utc(2022, 1, 1, 10, 0),
        endDate: DateTime.utc(2022, 1, 1, 12, 0),
        organizer: Organizer(
          name: 'John Smith',
          email: 'john@example.com',
        ),
        recurrenceRule: RecurrenceRule(
          frequency: Frequency.WEEKLY,
          interval: 2,
          count: 10,
        ),
      );

      expect(Event.fromICalString(icalString), equals(expected));
    });
  });

  group('ics file import', () {
    test('should parse a valid ics file', () {
      final icsFile = File('test/ics/icalendar.ics');
      final icsString = icsFile.readAsStringSync();

      final calendar1 = ICalendar.fromICalString(icsString);
      final calendar2 = ICalendar.fromICalString(calendar1.toICalString());

      expect(calendar1.events?.length, calendar2.events?.length);
      expect(calendar1.toICalString(), calendar2.toICalString());
      expect(calendar1.properties?.length, calendar2.properties?.length);
    });
  });

  // test('custom/icalendar_parser#1', () {
  //   final icsFile = File('test/ics/custom.ics');
  //   final icsString = icsFile.readAsStringSync();

  //   final calendar = ICalendar.fromICalString(icsString);
  //   expect(calendar.toICalString(), icsString);
  // });
}
